==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebColumnPipeArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFieldPipeArgsDescriptionMetadata } from "./WebFieldPipeArgsDescriptionMetadata";
import { WebColumnPipeArgsDescription } from "./WebColumnPipeArgsDescription";
/**
 * @hidden
 */
export let WebColumnPipeArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebColumnPipeArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebColumnPipeArgsDescriptionMetadata.a == null) {
                WebColumnPipeArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebColumnPipeArgsDescriptionMetadata.c(WebColumnPipeArgsDescriptionMetadata.a);
            }
            if (a.j(WebColumnPipeArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(WebColumnPipeArgsDescriptionMetadata.a);
        }
        static c(a) {
            WebFieldPipeArgsDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:ColumnPipeArgs");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
        }
        static d(a) {
            WebColumnPipeArgsDescriptionMetadata.b(a);
            a.aa("WebColumnPipeArgs", () => new WebColumnPipeArgsDescription());
            a.z("WebColumnPipeArgs", WebColumnPipeArgsDescriptionMetadata.a);
        }
    }
    WebColumnPipeArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebColumnPipeArgsDescriptionMetadata, 'WebColumnPipeArgsDescriptionMetadata');
    WebColumnPipeArgsDescriptionMetadata.a = null;
    return WebColumnPipeArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebColumnPipeArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFieldPipeArgsDescriptionMetadata } from "./WebFieldPipeArgsDescriptionMetadata";
import { WebColumnPipeArgsDescription } from "./WebColumnPipeArgsDescription";
/**
 * @hidden
 */
export let WebColumnPipeArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebColumnPipeArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebColumnPipeArgsDescriptionMetadata.a == null) {
                WebColumnPipeArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebColumnPipeArgsDescriptionMetadata.c(WebColumnPipeArgsDescriptionMetadata.a);
            }
            if (a.k(WebColumnPipeArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebColumnPipeArgsDescriptionMetadata.a);
        }
        static c(a) {
            WebFieldPipeArgsDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:ColumnPipeArgs");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
        }
        static d(a) {
            WebColumnPipeArgsDescriptionMetadata.b(a);
            a.ac("WebColumnPipeArgs", () => new WebColumnPipeArgsDescription());
            a.ab("WebColumnPipeArgs", WebColumnPipeArgsDescriptionMetadata.a);
        }
    }
    WebColumnPipeArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebColumnPipeArgsDescriptionMetadata, 'WebColumnPipeArgsDescriptionMetadata');
    WebColumnPipeArgsDescriptionMetadata.a = null;
    return WebColumnPipeArgsDescriptionMetadata;
})();
